Crate allure_rust

Crate allure_rust 

allure-rust

A Rust library for generating Allure test reports with rich test execution details, steps, attachments, and more.

This is a facade crate that re-exports all functionality from allure-rust-core.

Quick Start

use allure_rust::{allure_test, allure_step};

#[allure_test("My first test")]
#[test]
fn test_example() {
    allure_step!("Step 1: Setup", {
        let value = 42;
        assert_eq!(value, 42);
    });

    allure_step!("Step 2: Verify", {
        assert!(true);
    });
}

For more examples and documentation, see the README.

Modules

attachment
models
writer

Macros

allure_step
json
Construct a serde_json::Value from a JSON literal.

Enums

AttachmentType

Traits

IntoAttachment

Functions

add_attachment
add_attachment_with_type
end_step
end_test
start_step
start_step_with_params
start_test
start_test_with_context
start_test_with_suite

Attribute Macros

allure_suite
allure_test
step