allure-rust
A Rust library for generating Allure test reports with rich test execution details, steps, attachments, and more.
This is a facade crate that re-exports all functionality from allure-rust-core.
Quick Start
use allure_rust::{allure_test, allure_step};
#[allure_test("My first test")]
#[test]
fn test_example() {
allure_step!("Step 1: Setup", {
let value = 42;
assert_eq!(value, 42);
});
allure_step!("Step 2: Verify", {
assert!(true);
});
}For more examples and documentation, see the README.
Modules
Macros
- allure_
step - json
- Construct a
serde_json::Valuefrom a JSON literal.
Enums
Traits
Functions
- add_
attachment - add_
attachment_ with_ type - end_
step - end_
test - start_
step - start_
step_ with_ params - start_
test - start_
test_ with_ context - start_
test_ with_ suite